@@ -4,7 +4,7 @@ import collections
 import hashlib
 
 class Simhash(object):
-    def __init__(self, value, f=64, reg=ur'[\w\u4e00-\u9fff]+'):
+    def __init__(self, value, f=64, reg=ur'(?:\w+|[\u4e00-\u9fff])'):
         self.f = f
         self.reg = reg
         self.value = None
@@ -17,8 +17,6 @@ class Simhash(object):
             self.build_by_features(value)
         elif isinstance(value, long):
             self.value = value
-        elif isinstance(value, Simhash):
-            self.value = value.hash
         else:
             raise Exception('Bad parameter')
 
@@ -27,16 +25,18 @@ class Simhash(object):
 
     def _tokenize(self, content):
         ans = []
-        content = ''.join(re.findall(self.reg, content))
+        content = content.lower()
+        content = re.findall(self.reg, content)
         ans = self._slide(content)
         return ans
 
     def build_by_text(self, content):
         features = self._tokenize(content)
+        features = [u'/'.join(f) for f in features]
+        self._features = features
         return self.build_by_features(features)
 
     def build_by_features(self, features):
-        features = set(features) # remove duplicated features
         hashs = [int(hashlib.md5(w.encode('utf-8')).hexdigest(), 16) for w in features]
         v = [0]*self.f
         for h in hashs:
